/*
 * Copyright (C) 2005-2017 Centre National d'Etudes Spatiales (CNES)
 *
 * This file is part of Orfeo Toolbox
 *
 *     https://www.orfeo-toolbox.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#include "otbUtils.h"
#include <sstream>

namespace otb
{

namespace Utils
{

bool IsLonLatValid(double lon, double lat)
{
  if (lon < -180.0) return false;
  if (lon > 180.0) return false;
  if (lat < -90.0) return false;
  if (lat > 90.0) return false;
  return true;
}

void PrintNothing(const char * /* s */)
{
}

bool const TrueConstant = true;

bool const FalseConstant = false;

}

}
